==> feature-toggle-service-0.16.0.tgz: package/migrations/mysql/migrations/sqls/20231222053654-initial-up.sql <==
-- creating features table
CREATE TABLE features (
	id                   VARCHAR(36) NOT NULL PRIMARY KEY,
  name                 VARCHAR(50) NOT NULL,
  `key`                VARCHAR(50) NOT NULL,
  description          VARCHAR(50),
  default_value        BOOL DEFAULT true NOT NULL,
  metadata             TEXT,  
  created_by           VARCHAR(100),
  modified_by          VARCHAR(100),
  created_on           TIMESTAMP DEFAULT current_timestamp NOT NULL,
  modified_on          TIMESTAMP DEFAULT current_timestamp NOT NULL,
  deleted              BOOL DEFAULT false NOT NULL,
  deleted_on           TIMESTAMP,
  deleted_by           VARCHAR(36)
);

-- adding triggers
CREATE TRIGGER before_insert_trigger_features
BEFORE INSERT ON features
FOR EACH ROW
SET NEW.id = IFNULL(NEW.id, uuid());

-- creating strategies table
CREATE TABLE strategies (
	id                   VARCHAR(36) NOT NULL PRIMARY KEY,
	name                 VARCHAR(50) NOT NULL,
	`key`                VARCHAR(50) NOT NULL,
	priority             INTEGER,
  created_by           VARCHAR(100),
  modified_by          VARCHAR(100),
  created_on           TIMESTAMP DEFAULT current_timestamp NOT NULL,
  modified_on          TIMESTAMP DEFAULT current_timestamp NOT NULL,
  deleted              BOOL DEFAULT false NOT NULL,
  deleted_on           TIMESTAMP,
  deleted_by           VARCHAR(36)
);

-- adding triggers
CREATE TRIGGER before_insert_trigger_strategies
BEFORE INSERT ON strategies
FOR EACH ROW
SET NEW.id = IFNULL(NEW.id, uuid());

-- creating feature_toggles table
CREATE TABLE feature_toggles (
	id                   VARCHAR(36) NOT NULL PRIMARY KEY,
	feature_key          VARCHAR(50) NOT NULL,
	strategy_key         VARCHAR(50) NOT NULL,
  strategy_entity_id   VARCHAR(36),
	status               BOOL DEFAULT true NOT NULL,
  created_by           VARCHAR(100),
  modified_by          VARCHAR(100),
  created_on           TIMESTAMP DEFAULT current_timestamp NOT NULL,
  modified_on          TIMESTAMP DEFAULT current_timestamp NOT NULL,
  deleted              BOOL DEFAULT false NOT NULL,
  deleted_on           TIMESTAMP,
  deleted_by           VARCHAR(36)
);

-- adding triggers
CREATE TRIGGER before_insert_trigger_feature_toggles
BEFORE INSERT ON feature_toggles
FOR EACH ROW
SET NEW.id = IFNULL(NEW.id, uuid());

-- inserting  data in tables
INSERT INTO strategies(name, `key`, priority) 
VALUES ('System', 'System', '1');

INSERT INTO strategies(name, `key`, priority) 
VALUES ('Tenant', 'Tenant', '2');

INSERT INTO strategies(name, `key`, priority) 
VALUES ('User', 'User', '3');

==> feature-toggle-service-3.1.3.tgz: package/migrations/mysql/migrations/sqls/20231222053654-initial-up.sql <==
-- creating features table
CREATE TABLE features (
	id                   TEXT NOT NULL PRIMARY KEY,
  name                 TEXT NOT NULL,
  `key`                TEXT NOT NULL,
  description          TEXT,
  default_value        TEXT NOT NULL,
  type                 TEXT NOT NULL,
  metadata             TEXT,  
  created_by           VARCHAR(100),
  modified_by          VARCHAR(100),
  created_on           TIMESTAMP DEFAULT current_timestamp NOT NULL,
  modified_on          TIMESTAMP DEFAULT current_timestamp NOT NULL,
  deleted              BOOL DEFAULT false NOT NULL,
  deleted_on           TIMESTAMP,
  deleted_by           VARCHAR(100)
);

-- adding triggers
CREATE TRIGGER before_insert_trigger_features
BEFORE INSERT ON features
FOR EACH ROW
SET NEW.id = IFNULL(NEW.id, uuid());

-- creating strategies table
CREATE TABLE strategies (
	id                   VARCHAR(36) NOT NULL PRIMARY KEY,
	name                 TEXT NOT NULL,
	`key`                TEXT NOT NULL,
	priority             INTEGER,
  created_by           VARCHAR(100),
  modified_by          VARCHAR(100),
  created_on           TIMESTAMP DEFAULT current_timestamp NOT NULL,
  modified_on          TIMESTAMP DEFAULT current_timestamp NOT NULL,
  deleted              BOOL DEFAULT false NOT NULL,
  deleted_on           TIMESTAMP,
  deleted_by           VARCHAR(100)
);

-- adding triggers
CREATE TRIGGER before_insert_trigger_strategies
BEFORE INSERT ON strategies
FOR EACH ROW
SET NEW.id = IFNULL(NEW.id, uuid());

-- creating feature_values table
CREATE TABLE feature_values (
	id                   VARCHAR(36) NOT NULL PRIMARY KEY,
	feature_key          TEXT NOT NULL,
	strategy_key         TEXT NOT NULL,
  strategy_entity_id   VARCHAR(36),
	status               BOOL DEFAULT true NOT NULL,
  values               TEXT,
  created_by           VARCHAR(100),
  modified_by          VARCHAR(100),
  created_on           TIMESTAMP DEFAULT current_timestamp NOT NULL,
  modified_on          TIMESTAMP DEFAULT current_timestamp NOT NULL,
  deleted              BOOL DEFAULT false NOT NULL,
  deleted_on           TIMESTAMP,
  deleted_by           VARCHAR(100)
);

-- adding triggers
CREATE TRIGGER before_insert_trigger_feature_values
BEFORE INSERT ON feature_values
FOR EACH ROW
SET NEW.id = IFNULL(NEW.id, uuid());

-- inserting  data in tables
INSERT INTO strategies(name, `key`, priority) 
VALUES ('System', 'System', '1');

INSERT INTO strategies(name, `key`, priority) 
VALUES ('Tenant', 'Tenant', '2');

INSERT INTO strategies(name, `key`, priority) 
VALUES ('User', 'User', '3');
